@@ -8,10 +8,9 @@ from plexapi.library import LibrarySection, ManagedHub
 from plexapi.mixins import (
     AdvancedSettingsMixin, SmartFilterMixin, HubsMixin, RatingMixin,
     ArtMixin, PosterMixin, ThemeMixin,
-    ContentRatingMixin, SortTitleMixin, SummaryMixin, TitleMixin,
+    AddedAtMixin, ContentRatingMixin, SortTitleMixin, SummaryMixin, TitleMixin,
     LabelMixin
 )
-from plexapi.playqueue import PlayQueue
 from plexapi.utils import deprecated
 
 
@@ -20,7 +19,7 @@ class Collection(
     PlexPartialObject,
     AdvancedSettingsMixin, SmartFilterMixin, HubsMixin, RatingMixin,
     ArtMixin, PosterMixin, ThemeMixin,
-    ContentRatingMixin, SortTitleMixin, SummaryMixin, TitleMixin,
+    AddedAtMixin, ContentRatingMixin, SortTitleMixin, SummaryMixin, TitleMixin,
     LabelMixin
 ):
     """ Represents a single Collection.
@@ -427,10 +426,6 @@ class Collection(
         """ Delete the collection. """
         super(Collection, self).delete()
 
-    def playQueue(self, *args, **kwargs):
-        """ Returns a new :class:`~plexapi.playqueue.PlayQueue` from the collection. """
-        return PlayQueue.create(self._server, self.items(), *args, **kwargs)
-
     @classmethod
     def _create(cls, server, title, section, items):
         """ Create a regular collection. """
