@@ -399,6 +399,10 @@ class AudioStream(MediaPartStream):
             self.peak = utils.cast(float, data.attrib.get('peak'))
             self.startRamp = data.attrib.get('startRamp')
 
+    def setDefault(self):
+        """ Sets this audio stream as the default audio stream. """
+        return self._parent().setDefaultAudioStream(self)
+
 
 @utils.registerPlexObject
 class SubtitleStream(MediaPartStream):
@@ -425,6 +429,10 @@ class SubtitleStream(MediaPartStream):
         self.headerCompression = data.attrib.get('headerCompression')
         self.transient = data.attrib.get('transient')
 
+    def setDefault(self):
+        """ Sets this subtitle stream as the default subtitle stream. """
+        return self._parent().setDefaultSubtitleStream(self)
+
 
 class LyricStream(MediaPartStream):
     """ Represents a lyric stream within a :class:`~plexapi.media.MediaPart`.
@@ -672,6 +680,7 @@ class MediaTag(PlexObject):
             role (str): The name of the character role for :class:`~plexapi.media.Role` only.
             tag (str): Name of the tag. This will be Animation, SciFi etc for Genres. The name of
                 person for Directors and Roles (ex: Animation, Stephen Graham, etc).
+            tagKey (str): Plex GUID for the actor/actress for :class:`~plexapi.media.Role` only.
             thumb (str): URL to thumbnail image for :class:`~plexapi.media.Role` only.
     """
 
@@ -687,6 +696,7 @@ class MediaTag(PlexObject):
         self.key = data.attrib.get('key')
         self.role = data.attrib.get('role')
         self.tag = data.attrib.get('tag')
+        self.tagKey = data.attrib.get('tagKey')
         self.thumb = data.attrib.get('thumb')
 
         parent = self._parent()
@@ -879,12 +889,15 @@ class Writer(MediaTag):
     FILTER = 'writer'
 
 
-class GuidTag(PlexObject):
-    """ Base class for guid tags used only for Guids, as they contain only a string identifier
+@utils.registerPlexObject
+class Guid(PlexObject):
+    """ Represents a single Guid media tag.
 
         Attributes:
+            TAG (str): 'Guid'
             id (id): The guid for external metadata sources (e.g. IMDB, TMDB, TVDB, MBID).
     """
+    TAG = 'Guid'
 
     def _loadData(self, data):
         """ Load attribute values from Plex XML response. """
@@ -893,13 +906,25 @@ class GuidTag(PlexObject):
 
 
 @utils.registerPlexObject
-class Guid(GuidTag):
-    """ Represents a single Guid media tag.
+class Rating(PlexObject):
+    """ Represents a single Rating media tag.
 
         Attributes:
-            TAG (str): 'Guid'
+            TAG (str): 'Rating'
+            image (str): The uri for the rating image
+                (e.g. ``imdb://image.rating``, ``rottentomatoes://image.rating.ripe``,
+                ``rottentomatoes://image.rating.upright``, ``themoviedb://image.rating``).
+            type (str): The type of rating (e.g. audience or critic).
+            value (float): The rating value.
     """
-    TAG = 'Guid'
+    TAG = 'Rating'
+
+    def _loadData(self, data):
+        """ Load attribute values from Plex XML response. """
+        self._data = data
+        self.image = data.attrib.get('image')
+        self.type = data.attrib.get('type')
+        self.value = utils.cast(float, data.attrib.get('value'))
 
 
 @utils.registerPlexObject
@@ -908,7 +933,7 @@ class Review(PlexObject):
 
         Attributes:
             TAG (str): 'Review'
-            filter (str): filter for reviews?
+            filter (str): The library filter for the review.
             id (int): The ID of the review.
             image (str): The image uri for the review.
             link (str): The url to the online review.
@@ -983,18 +1008,34 @@ class Chapter(PlexObject):
 
         Attributes:
             TAG (str): 'Chapter'
+            end (int): The end time of the chapter in milliseconds.
+            filter (str): The library filter for the chapter.
+            id (int): The ID of the chapter.
+            index (int): The index of the chapter.
+            tag (str): The name of the chapter.
+            title (str): The title of the chapter.
+            thumb (str): The URL to retrieve the chapter thumbnail.
+            start (int): The start time of the chapter in milliseconds.
     """
     TAG = 'Chapter'
 
+    def __repr__(self):
+        name = self._clean(self.firstAttr('tag'))
+        start = utils.millisecondToHumanstr(self._clean(self.firstAttr('start')))
+        end = utils.millisecondToHumanstr(self._clean(self.firstAttr('end')))
+        offsets = f'{start}-{end}'
+        return f"<{':'.join([self.__class__.__name__, name, offsets])}>"
+
     def _loadData(self, data):
         self._data = data
+        self.end = utils.cast(int, data.attrib.get('endTimeOffset'))
+        self.filter = data.attrib.get('filter')
         self.id = utils.cast(int, data.attrib.get('id', 0))
-        self.filter = data.attrib.get('filter')  # I couldn't filter on it anyways
+        self.index = utils.cast(int, data.attrib.get('index'))
         self.tag = data.attrib.get('tag')
         self.title = self.tag
-        self.index = utils.cast(int, data.attrib.get('index'))
+        self.thumb = data.attrib.get('thumb')
         self.start = utils.cast(int, data.attrib.get('startTimeOffset'))
-        self.end = utils.cast(int, data.attrib.get('endTimeOffset'))
 
 
 @utils.registerPlexObject
@@ -1003,6 +1044,12 @@ class Marker(PlexObject):
 
         Attributes:
             TAG (str): 'Marker'
+            end (int): The end time of the marker in milliseconds.
+            final (bool): True if the marker is the final credits marker.
+            id (int): The ID of the marker.
+            type (str): The type of marker.
+            start (int): The start time of the marker in milliseconds.
+            version (int): The Plex marker version.
     """
     TAG = 'Marker'
 
@@ -1015,10 +1062,25 @@ class Marker(PlexObject):
 
     def _loadData(self, data):
         self._data = data
+        self.end = utils.cast(int, data.attrib.get('endTimeOffset'))
+        self.final = utils.cast(bool, data.attrib.get('final'))
         self.id = utils.cast(int, data.attrib.get('id'))
         self.type = data.attrib.get('type')
         self.start = utils.cast(int, data.attrib.get('startTimeOffset'))
-        self.end = utils.cast(int, data.attrib.get('endTimeOffset'))
+
+        attributes = data.find('Attributes')
+        self.version = attributes.attrib.get('version')
+
+    @property
+    def first(self):
+        """ Returns True if the marker in the first credits marker. """
+        if self.type != 'credits':
+            return None
+        first = min(
+            (marker for marker in self._parent().markers if marker.type == 'credits'),
+            key=lambda m: m.start
+        )
+        return first == self
 
 
 @utils.registerPlexObject
@@ -1027,13 +1089,15 @@ class Field(PlexObject):
 
         Attributes:
             TAG (str): 'Field'
+            locked (bool): True if the field is locked.
+            name (str): The name of the field.
     """
     TAG = 'Field'
 
     def _loadData(self, data):
         self._data = data
-        self.name = data.attrib.get('name')
         self.locked = utils.cast(bool, data.attrib.get('locked'))
+        self.name = data.attrib.get('name')
 
 
 @utils.registerPlexObject
