@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 from datetime import datetime
 
-from urllib.parse import parse_qsl, quote_plus, unquote, urlencode, urlsplit
+from urllib.parse import parse_qsl, quote, quote_plus, unquote, urlencode, urlsplit
 
 from plexapi import media, settings, utils
 from plexapi.exceptions import BadRequest, NotFound
-from plexapi.utils import deprecated
+from plexapi.utils import deprecated, openOrRead
 
 
 class AdvancedSettingsMixin:
@@ -341,14 +341,14 @@ class ArtMixin(ArtUrlMixin):
         
             Parameters:
                 url (str): The full URL to the image to upload.
-                filepath (str): The full file path the the image to upload.
+                filepath (str): The full file path the the image to upload or file-like object.
         """
         if url:
             key = f'/library/metadata/{self.ratingKey}/arts?url={quote_plus(url)}'
             self._server.query(key, method=self._server._session.post)
         elif filepath:
             key = f'/library/metadata/{self.ratingKey}/arts'
-            data = open(filepath, 'rb').read()
+            data = openOrRead(filepath)
             self._server.query(key, method=self._server._session.post, data=data)
         return self
 
@@ -392,14 +392,14 @@ class BannerMixin(BannerUrlMixin):
         
             Parameters:
                 url (str): The full URL to the image to upload.
-                filepath (str): The full file path the the image to upload.
+                filepath (str): The full file path the the image to upload or file-like object.
         """
         if url:
             key = f'/library/metadata/{self.ratingKey}/banners?url={quote_plus(url)}'
             self._server.query(key, method=self._server._session.post)
         elif filepath:
             key = f'/library/metadata/{self.ratingKey}/banners'
-            data = open(filepath, 'rb').read()
+            data = openOrRead(filepath)
             self._server.query(key, method=self._server._session.post, data=data)
         return self
 
@@ -448,14 +448,14 @@ class PosterMixin(PosterUrlMixin):
 
             Parameters:
                 url (str): The full URL to the image to upload.
-                filepath (str): The full file path the the image to upload.
+                filepath (str): The full file path the the image to upload or file-like object.
         """
         if url:
             key = f'/library/metadata/{self.ratingKey}/posters?url={quote_plus(url)}'
             self._server.query(key, method=self._server._session.post)
         elif filepath:
             key = f'/library/metadata/{self.ratingKey}/posters'
-            data = open(filepath, 'rb').read()
+            data = openOrRead(filepath)
             self._server.query(key, method=self._server._session.post, data=data)
         return self
 
@@ -494,22 +494,24 @@ class ThemeMixin(ThemeUrlMixin):
         """ Returns list of available :class:`~plexapi.media.Theme` objects. """
         return self.fetchItems(f'/library/metadata/{self.ratingKey}/themes', cls=media.Theme)
 
-    def uploadTheme(self, url=None, filepath=None):
+    def uploadTheme(self, url=None, filepath=None, timeout=None):
         """ Upload a theme from url or filepath.
 
             Warning: Themes cannot be deleted using PlexAPI!
 
             Parameters:
                 url (str): The full URL to the theme to upload.
-                filepath (str): The full file path to the theme to upload.
+                filepath (str): The full file path to the theme to upload or file-like object.
+                timeout (int, optional): Timeout, in seconds, to use when uploading themes to the server.
+                    (default config.TIMEOUT).
         """
         if url:
             key = f'/library/metadata/{self.ratingKey}/themes?url={quote_plus(url)}'
-            self._server.query(key, method=self._server._session.post)
+            self._server.query(key, method=self._server._session.post, timeout=timeout)
         elif filepath:
             key = f'/library/metadata/{self.ratingKey}/themes'
-            data = open(filepath, 'rb').read()
-            self._server.query(key, method=self._server._session.post, data=data)
+            data = openOrRead(filepath)
+            self._server.query(key, method=self._server._session.post, data=data, timeout=timeout)
         return self
 
     def setTheme(self, theme):
@@ -555,6 +557,24 @@ class EditFieldMixin:
         return self._edit(**edits)
 
 
+class AddedAtMixin(EditFieldMixin):
+    """ Mixin for Plex objects that can have an added at date. """
+
+    def editAddedAt(self, addedAt, locked=True):
+        """ Edit the added at date.
+
+            Parameters:
+                addedAt (int or str or datetime): The new value as a unix timestamp (int),
+                    "YYYY-MM-DD" (str), or datetime object.
+                locked (bool): True (default) to lock the field, False to unlock the field.
+        """
+        if isinstance(addedAt, str):
+            addedAt = int(round(datetime.strptime(addedAt, '%Y-%m-%d').timestamp()))
+        elif isinstance(addedAt, datetime):
+            addedAt = int(round(addedAt.timestamp()))
+        return self.editField('addedAt', addedAt, locked=locked)
+
+
 class ContentRatingMixin(EditFieldMixin):
     """ Mixin for Plex objects that can have a content rating. """
 
@@ -588,7 +608,7 @@ class OriginallyAvailableMixin(EditFieldMixin):
         """ Edit the originally available date.
 
             Parameters:
-                originallyAvailable (str or datetime): The new value (YYYY-MM-DD) or datetime object.
+                originallyAvailable (str or datetime): The new value "YYYY-MM-DD (str) or datetime object.
                 locked (bool): True (default) to lock the field, False to unlock the field.
         """
         if isinstance(originallyAvailable, datetime):
@@ -724,7 +744,7 @@ class PhotoCapturedTimeMixin(EditFieldMixin):
         """ Edit the photo captured time.
 
             Parameters:
-                capturedTime (str or datetime): The new value (YYYY-MM-DD hh:mm:ss) or datetime object.
+                capturedTime (str or datetime): The new value "YYYY-MM-DD hh:mm:ss" (str) or datetime object.
                 locked (bool): True (default) to lock the field, False to unlock the field.
         """
         if isinstance(capturedTime, datetime):
@@ -802,7 +822,7 @@ class EditTagsMixin:
 
         if remove:
             tagname = f'{tag}[].tag.tag-'
-            data[tagname] = ','.join([str(t) for t in items])
+            data[tagname] = ','.join([quote(str(t)) for t in items])
         else:
             for i, item in enumerate(items):
                 tagname = f'{str(tag)}[{i}].tag.tag'
